package
Version:
v0.0.0-...-56e9cef
Opens a new window with list of versions in this module.
Published: Jun 30, 2022
License: MIT
Opens a new window with license information.
Imports: 10
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Copyright © 2022 NAME HERE <EMAIL ADDRESS>
Official < Common(Third Party) < Same module
type Entry struct {
Contents string
Weight int
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.